@@ -17,7 +17,7 @@ try:
   from tqdm import tqdm
   
 
-except:
+except ImportError:
   print("Installing dependencies of build...")
   os.system("pip install tqdm")
 
